@@ -1,7 +1,7 @@
 """
 Type annotations for sdb service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/literals.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sdb/literals/)
 
 Usage::
 
@@ -26,6 +26,7 @@ __all__ = (
     "ServiceName",
     "ResourceServiceName",
     "PaginatorName",
+    "RegionName",
 )
 
 
@@ -69,6 +70,7 @@ ServiceName = Literal[
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-media-pipelines",
     "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
@@ -150,6 +152,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -183,6 +186,7 @@ ServiceName = Literal[
     "iottwinmaker",
     "iotwireless",
     "ivs",
+    "ivschat",
     "kafka",
     "kafkaconnect",
     "kendra",
@@ -251,6 +255,7 @@ ServiceName = Literal[
     "pinpoint",
     "pinpoint-email",
     "pinpoint-sms-voice",
+    "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
     "proton",
@@ -348,3 +353,13 @@ ResourceServiceName = Literal[
     "sqs",
 ]
 PaginatorName = Literal["list_domains", "select"]
+RegionName = Literal[
+    "ap-northeast-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "eu-west-1",
+    "sa-east-1",
+    "us-east-1",
+    "us-west-1",
+    "us-west-2",
+]
